@@ -6,6 +6,7 @@ predict.FGR <- function(object,newdata,times,...){
     rhs <- as.formula(delete.response(object$terms))
     EHF <- prodlim::model.design(rhs,
                                  newdata,
+                                 dropIntercept=TRUE,
                                  specialsDesign=TRUE)
     # }}}
     # {{{ covariate design matrices
@@ -16,7 +17,9 @@ predict.FGR <- function(object,newdata,times,...){
     # }}}
     args <- list(object=object$crrFit,cov1=cov1,cov2=cov2,...)
     args <- args[!sapply(args,is.null)]
+    ## warning("uuu")
     pred <- do.call("predict.crr",args)
+    ## warning("bbb")
     out <- pred[,-1,drop=FALSE]
     if (!missing(times)){
         tind <- prodlim::sindex(jump.times=pred[,1],eval.times=times)
